@@ -1,13 +1,16 @@
 from qtpy.QtGui import QColor, QFont, qGray, QGuiApplication
 from qtpy.QtCore import Qt, QCoreApplication
 from qtpy.QtWidgets import QWidget, QMainWindow, QDialog, QAbstractButton, QApplication
-from pyqt_svg_button import SvgButton
 
 import os, tempfile, posixpath, re
 import shutil
 
 import qtsass
 
+# Set attribute Qt::AA_EnableHighDpiScaling before QCoreApplication is created
+QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
+QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)  # HighDPI support
+QGuiApplication.setHighDpiScaleFactorRoundingPolicy(Qt.HighDpiScaleFactorRoundingPolicy.PassThrough)
 
 class QtSassTheme:
 
@@ -17,12 +20,6 @@ class QtSassTheme:
         icon_path = cur_dir.replace(os.path.sep, posixpath.sep)
         ico_filename = os.path.join(icon_path, 'ico/_icons.scss').replace(os.path.sep, posixpath.sep)
         self.__setIcoPath(ico_filename, icon_path)
-        self.__prepareFineLookingGUI()
-
-    def __prepareFineLookingGUI(self):
-        QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
-        QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)  # HighDPI support
-        QGuiApplication.setHighDpiScaleFactorRoundingPolicy(Qt.HighDpiScaleFactorRoundingPolicy.PassThrough)
 
     def __setIcoPath(self, ico_filename: str, icon_path: str):
         import_abspath_str = f'$icopath: \'{icon_path}/\';'
@@ -54,6 +51,26 @@ class QtSassTheme:
                 f.seek(0, 0)
                 f.write(custom_theme_code + ''.join(fdata.splitlines(True)[1:]))
 
+    def __setFont(self, var_filename: str, font):
+        bold = 'bold' if font.bold() else ''
+        italic = 'italic' if font.italic() else ''
+        size = f"{font.pointSize()}pt"
+        family = f'"{font.family()}"'
+        fontattr = ' '.join([bold, italic, size, family]).strip()
+        with open(var_filename, 'r+') as f:
+            fdata = f.read()
+            regex = re.compile(r'\$fontattr:(.+)')
+            custom_theme_code = f'$fontattr: {fontattr};\n'
+            idx = 0
+            lines = fdata.split('\n')
+            for i, line in enumerate(lines):
+                if regex.search(line):
+                    idx = i
+                    break
+            lines[idx] = custom_theme_code
+            new_text = '\n'.join(lines)
+            f.write(new_text)
+
     def __setBackgroundPolicy(self, var_filename: str, background_darker=False):
         if background_darker:
              with open(var_filename, 'r+') as f:
@@ -72,32 +89,6 @@ class QtSassTheme:
         else:
             pass
 
-    def __setFontSize(self, var_filename, font_size):
-        font = QApplication.font()
-        family_name = QApplication.font().family()
-        font.setFamily(family_name)
-        font.setPointSize(font_size)
-        font.setStyleStrategy(QFont.PreferAntialias)
-        QApplication.setFont(font)
-
-        # with open(var_filename, 'r') as f:
-        #     lines = f.readlines()
-        #
-        # new_line_for_font_size = f'$fontsize: {font_size}pt;'
-        #
-        # idx_to_replace = 0
-        #
-        # for i, line in enumerate(lines):
-        #     if 'fontsize' in line:
-        #         idx_to_replace = i
-        #         break
-        #
-        # lines[idx_to_replace] = new_line_for_font_size
-        #
-        # with open(var_filename, 'w') as f:
-        #     f.writelines(lines)
-
-
     def __getStyle(self, filename):
         cur_dir = os.path.dirname(__file__)
         sass_dirname = os.path.join(cur_dir, 'sass')
@@ -106,7 +97,7 @@ class QtSassTheme:
         css = qtsass.compile_filename(os.path.join(sass_dirname, filename), temp_file)
         return css
 
-    def getThemeFiles(self, theme: str = 'dark_gray', font_size=9, background_darker=False, output_path=os.getcwd()):
+    def getThemeFiles(self, theme: str = 'dark_gray', font=QFont('Arial', 9), background_darker=False, output_path=os.getcwd()):
         theme_lst = ['dark_gray', 'dark_blue', 'light_gray', 'light_blue']
         cur_dir = os.path.dirname(__file__)
         official_theme_flag = theme in theme_lst
@@ -166,13 +157,9 @@ class QtSassTheme:
         else:
             self.__setCustomThemeColor(var_filename, theme)
         self.__setBackgroundPolicy(var_filename, background_darker)
-        self.__setFontSize(var_filename, font_size)
+        self.__setFont(var_filename, font)
 
-        # fade menu and tooltip
-        QApplication.setEffectEnabled(Qt.UI_FadeMenu, True)
-        QApplication.setEffectEnabled(Qt.UI_FadeTooltip, True)
-
-    def setThemeFiles(self, main_window: QWidget, input_path='res', exclude_type_lst: list = []):
+    def setThemeFiles(self, main_window: QWidget, input_path='res'):
         if os.path.basename(os.getcwd()) != input_path:
             input_path = os.path.join(os.getcwd(), input_path)
             os.chdir(input_path)
@@ -189,13 +176,13 @@ class QtSassTheme:
 
         os.chdir('../')
         if os.path.isdir(input_path):
-            f_lst = ['theme.css', 'main_widget.css', 'icon_button.css', 'icon_text_button.css', 'menu_bar.css']
+            f_lst = ['theme.css', 'custom_widget.css', 'icon_button.css', 'icon_text_button.css', 'menu_bar.css']
             f_lst = [os.path.join(input_path, f) for f in f_lst]
 
             with open(f_lst[0], 'r') as f:
                 theme_style = f.read()
             with open(f_lst[1], 'r') as f:
-                main_widget_style = f.read()
+                custom_widget_style = f.read()
             with open(f_lst[2], 'r') as f:
                 icon_button_style = f.read()
             with open(f_lst[3], 'r') as f:
@@ -203,11 +190,9 @@ class QtSassTheme:
             with open(f_lst[4], 'r') as f:
                 menu_bar_style = f.read()
 
-            if isinstance(main_window, QMainWindow) or isinstance(main_window, QDialog):
-                main_window.setStyleSheet(theme_style)
-            else:
-                main_window.setObjectName('mainWidget')
-                main_window.setStyleSheet(theme_style + main_widget_style)
+            main_window.setStyleSheet(theme_style +
+                                      custom_widget_style +
+                                      menu_bar_style)
 
             # button
             def setButtonStyle(main_window):
@@ -215,34 +200,11 @@ class QtSassTheme:
                 for btn in btns:
                     # check if text exists
                     if btn.text().strip() == '':
-                        # if button type is SvgButton, let it keep its own style
-                        if isinstance(btn, SvgButton):
-                            pass
-                        else:
-                            btn.setStyleSheet(icon_button_style)  # no text - icon button style
+                        btn.setStyleSheet(icon_button_style)  # no text - icon button style
                     else:
-                        # if button type is SvgButton, let it maintain its own style
-                        if isinstance(btn, SvgButton):
-                            pass
-                        else:
-                            btn.setStyleSheet(icon_text_button_style)  # text - icon-text button style
+                        btn.setStyleSheet(icon_text_button_style)  # text - icon-text button style
 
-            # check exclusion of QAbstractButton
-            if QAbstractButton in exclude_type_lst:
-                pass
-            else:
-                setButtonStyle(main_window)
-
-            # todo check exclusion of other types
-            if len(exclude_type_lst) > 0:
-                for _type in exclude_type_lst:
-                    widgets = main_window.findChildren(_type)
-                    if isinstance(_type, QAbstractButton):
-                        print(_type)
-
-            if isinstance(main_window, QMainWindow):
-                menu_bar = main_window.menuBar()  # menu bar
-                menu_bar.setStyleSheet(menu_bar_style)
+            setButtonStyle(main_window)
 
     def getThemeStyle(self):
         css = self.__getStyle('theme.scss')
@@ -260,7 +222,3 @@ class QtSassTheme:
         css = self.__getStyle('menu_bar.scss')
         return css
 
-    def getMainWidgetStyle(self):
-        css = self.__getStyle('main_widget.scss')
-        return css
-
